changeset 1325:84ea83668304

Redid comments, reset all rev nibbles that weren't explictly set to 0
author boisy
date Thu, 04 Sep 2003 23:06:16 +0000
parents 3ddd71e69da8
children 57f23da9790a
files level1/cmds/asm.asm level1/cmds/attr.asm level1/cmds/backup.asm level1/cmds/binex.asm level1/cmds/build.asm level1/cmds/cmp.asm level1/cmds/cobbler.asm level1/cmds/copy.asm level1/cmds/cputype.asm level1/cmds/date.asm level1/cmds/dcheck.asm level1/cmds/debug.asm level1/cmds/deiniz.asm level1/cmds/del.asm level1/cmds/deldir.asm level1/cmds/devs.asm level1/cmds/dir.asm level1/cmds/disasm.asm level1/cmds/display.asm level1/cmds/dmode.asm level1/cmds/dsave.asm level1/cmds/dump.asm level1/cmds/echo.asm level1/cmds/edit.asm level1/cmds/error.asm level1/cmds/exbin.asm level1/cmds/format.asm level1/cmds/free.asm level1/cmds/grfo.asm level1/cmds/help.asm level1/cmds/ident.asm level1/cmds/iniz.asm level1/cmds/irqs.asm level1/cmds/link.asm level1/cmds/list.asm level1/cmds/load.asm level1/cmds/login.asm level1/cmds/makdir.asm level1/cmds/mdir.asm level1/cmds/merge.asm level1/cmds/mfree.asm level1/cmds/ngu.asm level1/cmds/os9gen.asm level1/cmds/park.asm level1/cmds/pd.asm level1/cmds/printerr.asm level1/cmds/procs.asm level1/cmds/prompt.asm level1/cmds/rename.asm level1/cmds/save.asm level1/cmds/setime.asm level1/cmds/shell_21.asm level1/cmds/sleep.asm level1/cmds/tee.asm level1/cmds/tmode.asm level1/cmds/touch.asm level1/cmds/tsmon.asm level1/cmds/tuneport.asm level1/cmds/unlink.asm level1/cmds/verify.asm level1/cmds/xmode.asm
diffstat 61 files changed, 499 insertions(+), 280 deletions(-) [+]
line wrap: on
line diff
--- a/level1/cmds/asm.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/asm.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -8,11 +8,17 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   6    Made compliant with 1900-2155                  BGP 99/05/11
-*   7    Added 6309 bitfield instructions               RVH 03/06/27
-*   8    Enabled underscore and lowercase in symbols    RVH 03/07/28
+*   6      1999/05/11  Boisy G. Pitre
+* Made compliant with 1900-2155.
+*
+*   7      2003/06/27  Rodney V. Hamilton
+* Added 6309 bitfield instructions.
+*
+*   8      2003/07/28  Rodney V. Hamilton
+* Enabled underscore and lowercase in symbols.
 
          nam   Asm
          ttl   6809/6309 Assembler
--- a/level1/cmds/attr.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/attr.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  11    From Tandy OS-9 Level Two VR 02.00.01
+*  11      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
 
          nam   Attr
          ttl   Modify file attributes
@@ -21,7 +23,7 @@
 
 tylg     set   Prgrm+Objct
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   11
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/backup.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/backup.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   8    From Tandy OS-9 Level One VR 02.00.00
+*   8      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
 
          nam   Backup
          ttl   Make a backup copy of a disk
@@ -20,7 +22,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   $08
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/binex.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/binex.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  67    From Tandy OS-9 Level One VR 02.00.00
-*  68    Set proper edition
-*   1    Restarted edition, removed Motorola copyright  BGP 03/01/14
+*  67      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
+*
+*  68      2003/01/14  Boisy G. Pitre
+* Restarted edition; removed Motorola copyright.
 
 
          nam   Binex
@@ -21,7 +24,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   1
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/build.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/build.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   6    From Tandy OS-9 Level Two VR 02.00.01
+*   6      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
 
          nam   Build
          ttl   Simple text file creation utility
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   6
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/cmp.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/cmp.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    Rewritten in assembly for size                 BGP 03/01/20
+*   1      2003/01/20  Boisy G. Pitre
+* Rewritten in assembly for size.
 
          nam   Cmp
          ttl   Binary file comparison utility
@@ -24,7 +26,7 @@
 * Module header definitions
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   1
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/cobbler.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/cobbler.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   7    From Tandy OS-9 Level Two Vr. 2.00.01
-*        Modified source to allow for OS-9 Level One    BGP 02/07/20
-*        and OS-9 Level Two assembly
+*   7      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
+*
+*          2002/07/20  Boisy G. Pitre
+* Modified source to allow for OS-9 Level One and Level Two assembly.
 
          nam   Cobbler
          ttl   Write OS9Boot to a disk
@@ -23,7 +26,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   7
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/copy.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/copy.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,17 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   9    From Tandy OS-9 Level One VR 02.00.00
-*  10    Reworked                                       RML
-*  11    Added useful options, made more robust         BGP 03/01/11
+*   9      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
+*
+*  10      ????/??/??  Ron Lamardo
+* Reworked.
+*
+*  11      2003/01/11  Boisy G. Pitre
+* Added useful options, made more robust.
 
          nam   Copy
          ttl   File copy utility
@@ -21,7 +27,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   11
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/cputype.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/cputype.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,12 +3,17 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    Started                                        ADK ??/??/??
-*   2r1  Fixed a crash bug on 6809, now just reports    BGP 03/04/02
-*        6809 message on a 6809
-*   3r1  Rearranged code, used short offsets            RVH 03/04/23
+*   1      ????/??/??  Alan DeKok
+* Started.
+*
+*   2      2003/04/02  Boisy G. Pitre
+* Fixed a crash bug on 6809, now just reports 6809 message on a 6809.
+*
+*   3      2003/04/23  Rodney V. Hamilton
+* Rearranged code, used short offsets.
 
          nam   CPUType
          ttl   Identify 6809 or 6309
@@ -19,7 +24,7 @@
 
 tylg     set   Prgrm+Objct
 atrv     set   ReEnt+Rev
-rev      set   1
+rev      set   $00
 edition  set   3
 
          org   0
--- a/level1/cmds/date.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/date.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -24,11 +24,17 @@
 * 
 * Gene Heskett, <gene_heskett@wvlink.mpl.com>
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-* 5      Made Y2K compliant                             GH  96/09/25
-* 6      Made compliant with 1900-2155                  BGP 99/05/07
-* 7      New option is now -t, code compacted a bit     BGP 03/01/14
+*   5      1996/09/25  Gene Heskett
+* Made Y2K compliant.
+*
+*   6      1999/05/07  Boisy G. Pitre
+* Made compliant with 1900-2155.
+*
+*   7      2003/01/14  Boisy G. Pitre
+* New option is now -t, code compacted a bit.
 
          nam   Date
          ttl   Print Date/Time
@@ -39,7 +45,7 @@
 
 tylg     set   Prgrm+Objct
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   7
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/dcheck.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/dcheck.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,17 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   4    From Tandy OS-9 Level One VR 02.00.00
-*   5    Changed /D0 references to /DD                  BGP 02/07/21
-*        Completly disasemble to be more readable       JB  03/03/31
+*   4      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+* 
+*   5      2002/07/21  Boisy G. Pitre
+* Changed /D0 references to /DD.
+*
+*          2003/03/31  JB
+* Completly disasembly to be more readable.
 
          nam   dcheck
          ttl   Check Disk File Structure
@@ -20,7 +26,7 @@
          
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   $05
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/debug.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/debug.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,12 +3,18 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   6    From Tandy OS-9 Level One VR 02.00.00
-*   9    From Tandy OS-9 Level Two Development System,  BGP 03/01/03
-*        back ported to OS-9 Level One
-*  10    Start of optimizations, works under NitrOS-9   BGP 03/01/05
+*   6      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
+*
+*   9      2003/01/03  Boisy G. Pitre
+* From Tandy OS-9 Level Two Development System, back-ported to
+* OS-9 Level One.
+*
+*  10      2003/01/05  Boisy G. Pitre
+* Start of optimizations, works under NitrOS-9.
 
          nam   debug
          ttl   6809/6309 debugger
@@ -26,7 +32,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   10
 
 L0000    mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/deiniz.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/deiniz.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   3    From Tandy OS-9 Level Two VR 02.00.01
-*   4    Tightened code, changed behavior slightly      BGP 03/01/13
+*   3      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
+*
+*   4      2003/01/13  Boisy G. Pitre
+* Tightened code, changed behavior slightly.
 
          nam   DeIniz
          ttl   Deinitialize a device
@@ -21,7 +25,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   4
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/del.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/del.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,15 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   5    From Tandy OS-9 Level One VR 02.00.00
-*   6    Now option can be anywhere on command line,    BGP 03/01/13
-*        and all files will be deleted.  Made smaller
+*   5      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   6      2003/01/13  Boisy G. Pitre
+* Now option can be anywhere on command line, and all files will be
+* deleted.  Also made smaller.
 
          nam   Del
          ttl   File deletion utility
@@ -22,7 +26,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   6
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/deldir.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/deldir.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,17 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   3    From Tandy OS-9 Level Two VR 02.00.01
-*   4    Updated to add -e instead of e to dir          BGP 03/01/14
-*        Optimized for size.                            BGP 03/06/21
+*   3      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
+*
+*   4      2003/01/14  Boisy G. Pitre
+* Updated to add -e instead of e to dir.
+*
+*          2003/06/21  Boisy G. Pitre
+* Optimized for size.
 
          nam   Deldir
          ttl   Delete a directory
@@ -21,7 +27,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   4
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/devs.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/devs.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,17 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   2    Original version
-*   3    Reworked                                       AD
-*   4    Renamed to devs ala OS-9/68K, reworked         BGP 03/01/07
+*   2      ????/??/??
+* Original version.
+*
+*   3      ????/??/??  Alan DeKok
+* Reworked.
+*
+*   3      2003/01/07  Boisy G. Pitre
+* Renamed to devs ala OS-9/68K, reworked.
 
          nam   devs
          ttl   Show device table entries
@@ -18,7 +24,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   3
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/dir.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/dir.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -7,11 +7,15 @@
 * the OS-9 Level Two package, then incorporated Glenside's Y2K
 * fix.
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-* 10     Incorporated Glenside Y2K fixes                BGP 99/05/11
-* 11     Made option handling more flexible, now they   BGP 03/01/14
-*        must be preceeded by a dash
+*  10      1999/05/11  Boisy G. Pitre
+* Incorporated Glenside Y2K fixes.
+*
+*  11      2003/01/14  Boisy G. Pitre
+* Made option handling more flexible, now they must be preceeded
+* by a dash.
 
          nam   Dir
          ttl   Show directory
--- a/level1/cmds/disasm.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/disasm.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -1,30 +1,42 @@
-         nam   Disasm
-         ttl   Os9 disassembler by Ron Lammardo
-
+********************************************************************
+* Disasm - 6809/6309 disassembler
+*
+* $Id$
+*
 * Disasm v1.5 (c) 1988 by Ron Lammardo
 * 6309 additions by L. Curtis Boyle Jan. 1993
-********
-*
-* 03/12/87 (#2) - added code for line,address,obj display
-*                 added options 'o' and 'x'
 *
-* 04/02/87 (#3) - added code to provide commented disassembly
-*                 of device descriptors
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
+* ------------------------------------------------------------------
+*   2      1987/03/12  Ron Lammardo
+* Added code for line,address,obj display added options 'o' and 'x'.
 *
-* 11/16/87 (#4) - fixed restart link failure
-*                 added code to display direct page addresses
+*   3      1987/04/02  Ron Lammardo
+* Added code to provide commented disassembly of device descriptors.
+*
+*   4      1987/11/16  Ron Lammardo
+* Fixed restart link failure, added code to display direct page addresses.
 *
-* 02/22/88 (#5) - added code to display dp/u offsets
-*                 added code to display fcb bytes preceding eom
-*                 added code for z option (hex input disassembly) 
-*                 added code to display date/time run
+*   5      1988/02/22  Ron Lammardo
+* Added code to display dp/u offsets; added code to display fcb bytes
+* preceding eom; added code for z option (hex input disassembly); 
+* added code to display date/time run
+*
+*          1993/01/23  L. Curtis Boyle
+* Added code to handle 6309 instruction set additions
 *
-* 01/23/93      - added code to handle 6309 instruction set additions
+*          2003/04/22  Rodney V. Hamilton
+* Added 4-digit year output.
+*
+*          2003/07/09  Rodney V. Hamilton
+* Changed output format of 6309 Bit commands.
 *
-* 04/22/03      - added 4-digit year output
-* 07/09/03      - changed output format of 6309 Bit commands
-* 08/14/03      - added code to output "end" line
-********
+*          2003/08/14  Rodney V. Hamilton
+* Added code to output "end" line
+
+         nam   Disasm
+         ttl   6809/6309 disassembler
 
          ifp1
          use   defsfile
@@ -32,7 +44,7 @@
 
 typ      set   Prgrm+Objct
 attrev   set   ReEnt+revision
-revision set   1
+revision set   $00
 edtn     set   5 edition
 edition  equ   $30+edtn ascii edition
 
--- a/level1/cmds/display.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/display.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-* 2      Original Tandy/Microware version
-* 3      Added decimal, text features                   ADK
+*   2      ????/??/??
+* Original Tandy/Microware version.
+*
+*   3      ????/??/??  Alan DeKok
+* Added decimal, text features.
 
          nam   Display
          ttl   Character display utility
--- a/level1/cmds/dsave.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/dsave.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -13,9 +13,11 @@
 *   -s = alter copy mem size
 *   -v = verify copied files
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    Put your development info here                 BGP 03/01/11
+*   1      2003/01/11  Boisy G. Pitre
+* Rewrote in assembly language.
 
          nam   dsave
          ttl   Multi-file copy utility
@@ -34,7 +36,7 @@
 * Module header definitions
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   1
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/dump.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/dump.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -10,19 +10,28 @@
 * In addition it now allows dumping of memory modules and command modules
 * in the execution directory.
 *
-* Ed.   Comments                                        Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   5   From Tandy OS-9 Level One VR 02.00.00
-*   6   Incorporated R. Telkman's additions from 1987,  BGP 02/12/23
-*       added -d option, added defs to conditionally
-*       assemble without help or screen size check
+*   5      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   6      2002/12/23  Boisy G. Pitre
+* Incorporated R. Telkman's additions from 1987, added -d option,
+* added defs to conditionally assemble without help or screen size check.
 *
-*       Removed -d option                               BGP 03/01/17
-*       Narrow screen now shows properly, only dumps    BGP 03/01/21
-*       16 bits worth of address data to make room.
-*       Fixed bug where header would be shown even if   BGP 03/03/03
-*       there was no data in a file.
-*   7   Restored Rubout processing for terminals        RVH 03/06/06
+*          2003/01/17  Boisy G. Pitre
+* Removed -d option.
+*
+*          2003/01/21  Boisy G. Pitre
+* Narrow screen now shows properly, only dumps 16 bits worth of address
+* data to make room.
+*
+*          2003/03/03  Boisy G. Pitre
+* Fixed bug where header would be shown even if there was no data in a file.
+*
+*   7      2003/06/06  Rodney V. Hamilton
+* Restored Rubout processing for terminals.
 
         nam     Dump
         ttl     Show file contents in hex
--- a/level1/cmds/echo.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/echo.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   5    From Tandy OS-9 Level One VR 02.00.00
+*   5      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Echo
          ttl   Echo text
--- a/level1/cmds/edit.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/edit.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   3    From Tandy OS-9 Level One VR 02.00.00
+*   3      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Edit
          ttl   Line editor
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   3
 
 L0000    mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/error.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/error.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -7,10 +7,14 @@
 *
 * Released under the GNU public licence
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    Rewrote in assembler for size                  RdV 03/01/20
-*        Ffixed problem with trailing space             RdV 03/01/21
+*   1      2003/01/20  Bob Devries
+* Rewrote in assembler for size.
+*
+*          2003/01/21  Bob Devries
+* Fixed problem with trailing space.
 
          nam   Error
          ttl   Show text error messags
@@ -21,7 +25,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   1
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/exbin.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/exbin.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  67    From Tandy OS-9 Level One VR 02.00.00
-*  68    Made proper edition number                     BGP 02/07/14
-*   1    Restarted edition, removed Motorola copyright  BGP 03/01/14
+*  67      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   1      2003/01/14  Boisy G. Pitre
+* Restarted edition, removed Motorola copyright.
 
          nam   Exbin
          ttl   Motorola S-Record utility
@@ -20,7 +23,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   1
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/format.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/format.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,18 +3,17 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  22    From Tandy OS-9 Level Two Vr. 2.00.01
+*  22      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
 *
-*  23    Format incorrect/clusters summary:             JC  03/01/06
-*        Now, specifying cluster size works.
-*
-*        Fixed bug where format showed an improper
-*        number of sectors formatted at the summary
-*        if the number of sectors was a large number.
-*        This was most notable when formatting large
-*        disks, such as hard drives.
+*  23      2003/01/06  JC
+* Format incorrect/clusters summary: now, specifying cluster size works.
+* Fixed bug where format showed an improper number of sectors formatted
+* at the summary if the number of sectors was a large number.
+* This was most notable when formatting large disks, such as hard drives.
 
          nam   Format
          ttl   Disk format program
@@ -31,7 +30,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   23
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/free.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/free.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   6    From Tandy OS-9 Level One VR 02.00.00
-*   7    Y2K fixed
+*   6      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   7      ????/??/??
+* Y2K fixed.
 
          nam   Free
          ttl   Print disk free space
--- a/level1/cmds/grfo.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/grfo.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    From Tandy OS-9 Level One VR 02.00.00
+*   1      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   GRFO
          ttl   Graphics module
@@ -18,7 +20,7 @@
 
 tylg     set   Systm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   1
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/help.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/help.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -1,13 +1,15 @@
-
 ********************************************************************
 * Help - Show help
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  6     Rewrote in assembler for size                  BGP 03/01/21
-*  7     Fixed showlist partial line bug, do auto list  RVH 03/05/30
+*   6      2003/01/21  Boisy G. Pitre
+*
+*   7      2003/05/30  Rodney V. Hamilton
+* Fixed showlist partial line bug, do auto list.
 
         nam     Help
         ttl     Show help
--- a/level1/cmds/ident.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/ident.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   7    From Tandy OS-9 Level One VR 02.00.00
-*   8    Now reports modules with a lang of Obj6309     BGP 03/04/11
+*   7      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   8      2003/04/11  Boisy G. Pitre
+* Now reports modules with a lang of Obj6309.
 
          nam   Ident
          ttl   Show module information
@@ -21,7 +25,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   8
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/iniz.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/iniz.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   3    From Tandy OS-9 Level Two VR 02.00.01
-*   4    Tightened code, changed behavior slightly      BGP 03/01/13
+*   3      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   4      2003/01/13  Boisy G. Pitre
+* Tightened code, changed behavior slightly.
 
          nam   Iniz
          ttl   Initialize a device
@@ -19,7 +23,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   4
 
 lsize    equ   80
--- a/level1/cmds/irqs.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/irqs.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,17 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    Created                                        KKD
-*   2    Modified                                       GH
-*   3    Streamlined and fixed problems                 BGP 03/01/07
+*   1      ????/??/??  Kevin Darling
+* Created.
+*
+*   2      ????/??/??  Gene Heskett
+* Modified.
+*
+*   3      2003/01/07  Boisy G. Pitre
+* Streamlined and fixed problems.
 
          nam   irqs
          ttl   Show interrupt polling table
@@ -16,7 +22,7 @@
          use   defsfile
          endc  
 
-rev      set   $01
+rev      set   $00
 edition  set   3
 
 MaxDEnts set   32	max device entries we will display
--- a/level1/cmds/link.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/link.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   5    From Tandy OS-9 Level One VR 02.00.00
+*   5      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Link
          ttl   Link to a module
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   5
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/list.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/list.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   5    From Tandy OS-9 Level One VR 02.00.00
+*   5      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   List
          ttl   List a text file
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   5
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/load.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/load.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   4    From Tandy OS-9 Level One VR 02.00.00
+*   4      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Load
          ttl   Load a module
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   4
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/login.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/login.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,13 +3,18 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  16    From Tandy OS-9 Level One VR 02.00.00
-*  17    Fixed for years 1900-2155                      BGP 99/05/11
-*  18    Changed icpt routine rts to rti, put in        BGP 02/07/20
-*        conditionals for Level One not to execute
-*        the os9 F$SUser command.
+*  16      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*  17      1999/05/11  Boisy G. Pitre
+* Fixed for years 1900-2155.
+*
+*  18      2002/07/20  Boisy G. Pitre
+* Changed icpt routine rts to rti, put in conditionals for Level One
+* not to execute the os9 F$SUser command.
 
          nam   Login
          ttl   Timeshare login utility
@@ -22,7 +27,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   18
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/makdir.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/makdir.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   4    From Tandy OS-9 Level One VR 02.00.00
-*   5    Makes multiple directories from a single       ADK
+*   4      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   5      ????/??/??  Alan DeKok
+* Makes multiple directories from a single pathlist.
 
          nam   Makdir
          ttl   Create directory file
@@ -19,7 +23,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   5
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/mdir.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/mdir.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,16 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   5    From Tandy OS-9 Level One VR 02.00.00
-*   6    Changed option to -e, optimized slightly       BGP 03/01/14
-*   7    Fixed leading zero supression, more optim      RVH 03/08/25
+*   5      ????/??/??
+*
+*   6      2003/01/14  Boisy G. Pitre
+* Changed option to -e, optimized slightly.
+*
+*   7      2003/08/25  Rodney V. Hamilton
+* Fixed leading zero supression, more optimizations.
 
          nam   Mdir
          ttl   Show module directory
@@ -20,7 +25,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   7
 stdout   set   1
 
--- a/level1/cmds/merge.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/merge.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   4    From OS-9 Level One VR 02.00.00
+*   4      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Merge
          ttl   Merge files into one file
@@ -16,7 +18,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   4
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/mfree.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/mfree.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   5    From Tandy OS-9 Level One VR 02.00.00
+*   5      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Mfree
          ttl   Show free memory
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   5
 stdout   set   1
 
--- a/level1/cmds/ngu.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/ngu.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -41,9 +41,11 @@
 *    - The current file counter is one byte, counting a maximum
 *      of 255 files.
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    Put your development info here                 BGP 03/01/11
+*   1      2003/01/11  Boisy G. Pitre
+* Put your development info here.
 
          nam   NGU
          ttl   The "Next Great Utility"
--- a/level1/cmds/os9gen.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/os9gen.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,14 +3,19 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   9    From OS-9 Level Two Vr. 2.00.01
-*  l0    Added -t= option, fixed bug in single disk     BGP 03/06/28
-*        swap routine if key besides 'C' was pressed,
-*        minor optimizations.
-*  l0r2  Fixed bug introduced in V03.01.03 where        BGP 03/07/24
-*        os9gen wouldn't write boot track on DS disks.
+*   9      ????/??/??
+* From OS-9 Level Two Vr. 2.00.01.
+*
+*  10      2003/06/28  Boisy G. Pitre
+* Added -t= option, fixed bug in single disk swap routine if key
+* besides 'C' was pressed, minor optimizations.
+*
+*  l0r2    2003/07/24  Boisy G. Pitre
+* Fixed bug introduced in V03.01.03 where os9gen wouldn't write boot
+* track on DS disks.
 
          nam   OS9Gen
          ttl   OS-9 bootfile generator
--- a/level1/cmds/park.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/park.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    From Tandy OS-9 Level One VR 02.00.00
-*   2    Changed name to a mixture of upper/lowercase   BGP 02/07/13
+*   1      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   2      2002/07/13  Boisy G. Pitre
+* Changed name to a mixture of upper/lowercase.
 
          nam   Park
          ttl   Park a hard drive
@@ -21,7 +25,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   2
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/pd.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/pd.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    From Tandy OS-9 Level One VR 02.00.00
+*   1      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   p[wx]d
          ttl   Print work/execution directory
@@ -19,7 +21,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   1
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/printerr.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/printerr.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   6    From Tandy OS-9 Level One VR 02.00.00
-*   7    Changed /D0 to /DD                             BGP 02/07/13
+*   6      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   7      2002/07/13  Boisy G. Pitre
+* Changed /D0 to /DD.
 
          nam   Printerr
          ttl   OS-9 Level One printerr routine
@@ -17,7 +21,7 @@
 
 tylg     set   Prgrm+Objct
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   7
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/procs.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/procs.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   9    From Tandy OS-9 Level One VR 02.00.00
-*  10    Now uses -e instead of e                       BGP 03/01/14
+*   9      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*  10      2003/01/14  Boisy G. Pitre
+* Now uses -e instead of e.
 
          nam   Procs
          ttl   program module       
@@ -19,7 +23,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   10
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/prompt.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/prompt.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    Created                                        BGP 03/06/28
+*   1      2003/06/28  Boisy G. Pitre
+* Created.
 
          nam   Prompt
          ttl   Echo text and wait for a key
--- a/level1/cmds/rename.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/rename.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   6    From Tandy OS-9 Level One VR 02.00.00
+*   6      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Rename
          ttl   Rename a file
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   6
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/save.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/save.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   3    From Tandy OS-9 Level One VR 02.00.00
+*   3      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Save
          ttl   Save module from memory to disk
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   3
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/setime.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/setime.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -24,12 +24,17 @@
 * this into the next century without any further concerns about
 * the "Y2K" problem.
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  10    Made Y2K compliant                             GH
-*  11    Made totally compliant for 1900-2155           BGP 99/05/07
-*  12    Typing a CR at the prompt no longer sets the   BGP 02/07/20
-*        time to a bogus value.
+*  10      ????/??/??  Gene Heskett
+* Made Y2K compliant.
+*
+*  11      1999/05/07  Boisy G. Pitre
+* Made totally compliant for 1900-2155.
+*
+*  12      2002/07/20  Boisy G. Pitre
+* Typing a CR at the prompt no longer sets the time to a bogus value.
 
          nam   Setime
          ttl   Set Date/Time
@@ -42,7 +47,7 @@
 
 tylg     set   Prgrm+Objct
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   12
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/shell_21.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/shell_21.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  20    From Tandy OS-9 Level One VR 02.00.00
-*  21    CHD no longer requires WRITE permission        BGP 02/04/05
+*  20      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*  21      2002/04/05  Boisy G. Pitre
+* CHD no longer requires WRITE permission.
 
          nam   Shell
          ttl   OS-9 Command Interpreter
@@ -19,7 +23,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   21
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/sleep.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/sleep.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   2    From Tandy OS-9 Level One VR 02.00.00
+*   2      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Sleep
          ttl   Sleep for some ticks
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   2
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/tee.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/tee.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   2    From Tandy OS-9 Level One VR 02.00.00
+*   2      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Tee
          ttl   Split output to multiple devices
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   2
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/tmode.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/tmode.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*  12    From Tandy OS-9 Level Two VR 02.00.01
+*  12      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
 
          nam   Tmode
          ttl   Change terminal parameters
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   12
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/touch.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/touch.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,11 +3,12 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   2    Rewrote touch from scratch, made almost 90%    BGP 03/01/11
-*        smaller than C version found in the OS-9
-*        Development System
+*   2      2003/01/11  Boisy G. Pitre
+* Rewrote touch from scratch, made almost 90% smaller than C version
+* found in the OS-9 Development System.
 
          nam   Touch
          ttl   Changes last modification date/time
@@ -26,7 +27,7 @@
 * Module header definitions
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   2
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/tsmon.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/tsmon.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   8    From Tandy OS-9 Level Two VR 02.00.01
+*   6      ????/??/??
+* From Tandy OS-9 Level Two VR 02.00.01.
 
          nam   Tsmon
          ttl   Timesharing monitor
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   8
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/tuneport.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/tuneport.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   3    From Tandy OS-9 Level One VR 02.00.00
+*   3      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   TunePort
          ttl   Tune Printer Port
@@ -19,7 +21,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   3
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/unlink.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/unlink.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   2    From Tandy OS-9 Level One VR 02.00.00
+*   2      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
 
          nam   Unlink
          ttl   Unlink memory module
@@ -18,7 +20,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   2
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/verify.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/verify.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,10 +3,14 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   5    From Tandy OS-9 Level One VR 02.00.00
-*   6    Option modified to require dash in frot        BGP 03/01/18
+*   5      ????/??/??
+* From Tandy OS-9 Level One VR 02.00.00.
+*
+*   6      2003/01/18  Boisy G. Pitre
+* Option modified to require dash in front.
 
          nam   Verify
          ttl   Verify a module's CRC
@@ -19,7 +23,7 @@
 
 tylg     set   Prgrm+Objct   
 atrv     set   ReEnt+rev
-rev      set   $01
+rev      set   $00
 edition  set   6
 
          mod   eom,name,tylg,atrv,start,size
--- a/level1/cmds/xmode.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/xmode.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -3,9 +3,11 @@
 *
 * $Id$
 *
-* Ed.    Comments                                       Who YY/MM/DD
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
 * ------------------------------------------------------------------
-*   1    Bruce Isted version released to PD             BRI 89/06/21
+*   1      1989/06/21  Bruce Isted
+* Released to public domain.
 
          nam   EXMode
          ttl   Extended SCF device descriptor utility
@@ -18,7 +20,7 @@
 Edtn     equ   1         
 MaxSize  equ   $80        maximum module size
 NameSize equ   4          maximum module name length
-Vrsn     equ   1         
+rev      equ   0         
 
          org   0         
 Count    rmb   1          number of option bytes
@@ -35,7 +37,7 @@
 stack    rmb   $0200      stack and parameter space
 MemSize  equ   .         
 
-         mod   Size,Name,Prgrm+Objct,ReEnt+Vrsn,Entry,MemSize
+         mod   Size,Name,Prgrm+Objct,ReEnt+rev,Entry,MemSize
 
 Name     fcs   "EXMode"   
          fcb   Edtn       edition number
--- a/level1/cmds/dmode.asm	Thu Sep 04 20:50:28 2003 +0000
+++ b/level1/cmds/dmode.asm	Thu Sep 04 23:06:16 2003 +0000
@@ -1,18 +1,8 @@
-         nam   dmode     
-
-* DMode   by Kevin K. Darling
-* Disk descriptor utility.
+********************************************************************
+* DMode - Disk mode utility
 *
-* This version will do desc file on disk also.
-* 23 Sept 86, 1 Oct 86, 2 Oct 86
-
-* Modified by Roger A. Krupski (HARDWAREHACK)
-* Fixes "lower case bug", allows "$" prefix for hex
-* Last updated: 08-24-89 RAK
-
-* Oversized and kludgy, but works.
-* Apologies for lack of comments.
-************************************************
+* $Id$
+*
 * RBF descriptor utility similar to xmode.
 * Use: dmode </devicename> [options]
 *      dmode -<filename>   [options]
@@ -26,7 +16,25 @@
 * dmode /d0
 * dmode -?
 * dmode -/d1/modules/d2.dd cyl=0028
+*
+* Apologies for lack of comments.
+*
+* Edt/Rev  YYYY/MM/DD  Modified by
+* Comment
+* ------------------------------------------------------------------
+*          1986/09/23  Kevin Darling
+*
+*          1986/10/01  Kevin Darling
+*
+*          1986/10/02  Kevin Darling
+*
+*          1989/08/24  Roger A. Krupski (HARDWAREHACK)
+* Fixed "lower case bug", allowed "$" prefix for hex
+* Oversized and kludgy, but works.
 
+         nam   DMode
+         ttl   Disk mode utility
+     
          ifp1            
          use   defsfile use defsfile
          use   rbfdefs